@@ -19,7 +19,7 @@ from lesscode.db.connection_info import ConnectionInfo
 from lesscode.db.es.es_pool import EsPool
 from lesscode.db.page import Page
 from lesscode.utils.EsUtil import format_es_param_result
-from lesscode.utils.aes import AES
+from lesscode.utils.encryption_algorithm import AES
 
 
 class EsHelper:
