@@ -14,7 +14,7 @@ import traceback
 from neo4j import WorkspaceConfig
 
 from lesscode.db.page import Page
-from lesscode.utils.aes import AES
+from lesscode.utils.encryption_algorithm import AES
 
 
 class Neo4jHelper:
