@@ -47,9 +47,10 @@ class RedisHelper:
             await self.get_connection().expire(name, time)
 
     async def hset(self, name, key=None, value=None, mapping=None, time=None):
-        await self.get_connection().hset(name, key=key, value=value, mapping=mapping)
+        con = self.get_connection()
+        await con.hset(name, key=key, value=value, mapping=mapping)
         if time:
-            await self.get_connection().expire(name, time)
+            await con.expire(name, time)
 
     async def hgetall(self, name):
         return await self.get_connection().hgetall(name)
@@ -75,8 +76,11 @@ class RedisHelper:
     async def hlen(self, name):
         return await self.get_connection().hlen(name)
 
-    async def hmset(self, name, mapping):
-        return await self.get_connection().hmset(name, mapping)
+    async def hmset(self, name, mapping, time=None):
+        con = self.get_connection()
+        await con.hmset(name, mapping)
+        if time:
+            await con.expire(name, time)
 
     async def hmget(self, name, keys, *args):
         return await self.get_connection().hmget(name, keys, *args)
@@ -87,8 +91,11 @@ class RedisHelper:
     async def hvals(self, name):
         return await self.get_connection().hvals(name)
 
-    async def sadd(self, name, *values):
-        return await self.get_connection().sadd(name, *values)
+    async def sadd(self, name, values: list, time=None):
+        con = self.get_connection()
+        await con.sadd(name, *values)
+        if time:
+            await con.expire(name, time)
 
     async def scard(self, name):
         return await self.get_connection().scard(name)
@@ -121,14 +128,16 @@ class RedisHelper:
             self.get_connection(sync=True).delete(names)
 
     def sync_rpush(self, name, values: list, time=None):
-        self.get_connection(sync=True).rpush(name, *values)
+        con = self.get_connection(sync=True)
+        con.rpush(name, *values)
         if time:
-            self.get_connection(sync=True).expire(name, time)
+            con.expire(name, time)
 
     def sync_hset(self, name, key=None, value=None, mapping=None, time=None):
-        self.get_connection(sync=True).hset(name, key=key, value=value, mapping=mapping)
+        con = self.get_connection(sync=True)
+        con.hset(name, key=key, value=value, mapping=mapping)
         if time:
-            self.get_connection(sync=True).expire(name, time)
+            con.expire(name, time)
 
     def sync_hgetall(self, name):
         return self.get_connection(sync=True).hgetall(name)
@@ -154,8 +163,11 @@ class RedisHelper:
     def sync_hlen(self, name):
         return self.get_connection(sync=True).hlen(name)
 
-    def sync_hmset(self, name, mapping):
-        return self.get_connection(sync=True).hmset(name, mapping)
+    def sync_hmset(self, name, mapping, time=None):
+        con = self.get_connection(sync=True)
+        con.hmset(name, mapping)
+        if time:
+            con.expire(name, time)
 
     def sync_hmget(self, name, keys, *args):
         return self.get_connection(sync=True).hmget(name, keys, *args)
@@ -166,8 +178,11 @@ class RedisHelper:
     def sync_hvals(self, name):
         return self.get_connection(sync=True).hvals(name)
 
-    def sync_sadd(self, name, *values):
-        return self.get_connection(sync=True).sadd(name, *values)
+    def sync_sadd(self, name, values: list, time=None):
+        con = self.get_connection(sync=True)
+        con.sadd(name, *values)
+        if time:
+            con.expire(name, time)
 
     def sync_scard(self, name):
         return self.get_connection(sync=True).scard(name)
