@@ -75,22 +75,25 @@ def eureka_request(path="", return_type="json", method="GET", data=None, app_nam
     return res
 
 
-def eureka_get(path="", return_type="json", data=None, app_name="DATA_SERVICE", pack=True, **kwargs):
+def eureka_get(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=True, **kwargs):
     if tornado.options.options.running_env != "local":
         res = eureka_request(path=path, return_type=return_type, method="GET", data=data, app_name=app_name, pack=pack,
                              **kwargs)
     else:
-        res = sync_get(path=path, params=data, base_url=tornado.options.options.data_server, result_type=return_type,
+        res = sync_get(path=path, params=data, base_url=kwargs.get("base_url") if kwargs.get(
+            "base_url") else tornado.options.options.data_server,
+                       result_type=return_type,
                        pack=pack, **kwargs)
     return res
 
 
-def eureka_post(path="", return_type="json", data=None, app_name="DATA_SERVICE", pack=True, **kwargs):
+def eureka_post(path="", data=None, return_type="json", app_name="DATA_SERVICE", pack=True, **kwargs):
     if tornado.options.options.running_env != "local":
         res = eureka_request(path=path, return_type=return_type, method="POST", data=json.dumps(data),
                              app_name=app_name,
                              pack=pack, **kwargs)
     else:
-        res = sync_post(path=path, data=data, base_url=tornado.options.options.data_server, result_type=return_type,
+        res = sync_post(path=path, data=data, base_url=kwargs.get("base_url") if kwargs.get(
+            "base_url") else tornado.options.options.data_server, result_type=return_type,
                         pack=pack, **kwargs)
     return res
